@@ -496,6 +496,7 @@ class TestBuild:
                         "targets": [],
                         "make_variables": {},
                         "kernel_image": build_attrs["kernel_image"],
+                        "is_public": True,
                     },
                 ],
                 "patches": {},
@@ -528,6 +529,7 @@ class TestBuild:
                         "targets": [],
                         "make_variables": {},
                         "kernel_image": build_attrs["kernel_image"],
+                        "is_public": True,
                     },
                 ],
                 "patches": {},
@@ -572,6 +574,7 @@ class TestBuild:
                         "targets": [],
                         "make_variables": {},
                         "kernel_image": build_attrs["kernel_image"],
+                        "is_public": True,
                     }
                 ],
                 "patches": {},
@@ -606,6 +609,7 @@ class TestBuild:
                         "environment": {},
                         "make_variables": {},
                         "kernel_image": build_attrs["kernel_image"],
+                        "is_public": True,
                     },
                 ],
                 "patches": {},
@@ -640,6 +644,7 @@ class TestBuild:
                         "environment": {},
                         "make_variables": {"W": "12", "LLVM": "1"},
                         "kernel_image": build_attrs["kernel_image"],
+                        "is_public": True,
                     },
                 ],
                 "patches": {},
@@ -673,6 +678,40 @@ class TestBuild:
                         "make_variables": {},
                         "kernel_image": build_attrs["kernel_image"],
                         "no_cache": True,
+                        "is_public": True,
+                    },
+                ],
+                "patches": {},
+            },
+        )
+
+    def test_submit_private_build(self, build, build_attrs, mocker):
+        build_attrs["is_public"] = False
+        post_request = mocker.patch("tuxsuite.build.post_request")
+        api_build_url = (
+            build_attrs["tuxapi_url"] + "/v1/groups/tuxsuite/projects/unittests/builds"
+        )
+
+        build.is_public = False
+        build.build()
+        post_request.assert_called_with(
+            api_build_url,
+            mocker.ANY,
+            {
+                "builds": [
+                    {
+                        "git_repo": build_attrs["git_repo"],
+                        "git_ref": build_attrs["git_ref"],
+                        "toolchain": build_attrs["toolchain"],
+                        "target_arch": build_attrs["target_arch"],
+                        "kconfig": [build_attrs["kconfig"]],
+                        "build_name": build_attrs["build_name"],
+                        "client_token": mocker.ANY,
+                        "environment": {},
+                        "targets": [],
+                        "make_variables": {},
+                        "kernel_image": build_attrs["kernel_image"],
+                        "is_public": False,
                     },
                 ],
                 "patches": {},
