@@ -179,7 +179,7 @@ class TestBakeCli:
         assert exc.value.code == 0
         assert exc.type == SystemExit
         output, error = capsys.readouterr()
-        assert "usage: tuxsuite bake [-h] {submit} ..." in output
+        assert "usage: tuxsuite bake [-h] {submit,cancel} ..." in output
 
     def test_bake(
         self, mocker, monkeypatch, tuxsuite_config, tmp_path, sample_bitbake_template
@@ -392,6 +392,7 @@ class TestBuildCli:
             image_sha=None,
             no_cache=False,
             patch_series=None,
+            is_public=True,
         )
 
     def test_build_download(self, mocker, monkeypatch, tuxsuite_config):
@@ -581,6 +582,7 @@ class TestBuildCli:
             image_sha=None,
             no_cache=False,
             patch_series=None,
+            is_public=True,
         )
 
     def test_build_no_make_targets(self, mocker, monkeypatch, tuxsuite_config):
@@ -617,6 +619,7 @@ class TestBuildCli:
             image_sha=None,
             no_cache=False,
             patch_series=None,
+            is_public=True,
         )
 
     def test_build_valid_make_vars(self, mocker, monkeypatch, tuxsuite_config):
@@ -693,6 +696,7 @@ class TestBuildCli:
             image_sha=None,
             no_cache=False,
             patch_series=None,
+            is_public=True,
         )
 
     def test_build_no_wait(self, mocker, monkeypatch, tuxsuite_config, tmp_path):
@@ -1636,3 +1640,29 @@ class TestBuildPatchSeries:
         )
         tuxsuite.cli.main()
         assert build.call_count == 1
+
+
+def test_oebuild_handle_cancel(mocker, config, response, monkeypatch):
+    monkeypatch.setattr(
+        sys, "argv", ["tuxsuite", "bake", "cancel", "205Yag6znViIi4oLWFVDxJC4avb"]
+    )
+    response.status_code = 200
+    response._content = {}
+    post_req = mocker.patch("requests.post", return_value=response)
+    tuxsuite.cli.main()
+    post_req.assert_called_with(
+        "https://tuxapi.tuxsuite.com/v1/groups/tuxsuite/projects/tux/oebuilds/205Yag6znViIi4oLWFVDxJC4avb/cancel",
+        headers={
+            "User-Agent": "tuxsuite.cli/0.1",
+            "Authorization": "Q9qMlmkjkIuIGmEAw-Mf53i_qoJ8Z2eGYCmrNx16ZLLQGrXAHRiN2ce5DGlAebOmnJFp9Ggcq9l6quZdDTtrkw",
+        },
+        json={},
+    )
+    assert post_req.call_count == 1
+
+    # Test failure case when the response is not 200
+    response.status_code = 500
+    post_req = mocker.patch("requests.post", return_value=response)
+    with pytest.raises(tuxsuite.exceptions.URLNotFound):
+        tuxsuite.cli.main()
+    assert post_req.call_count == 1
