@@ -17,7 +17,7 @@ def plan_json():
         "user_agent": None,
         "provisioning_time": "2021-11-01T19:38:31.142790",
         "builds": {
-            "count": 6,
+            "count": 8,
             "results": [
                 # Watch the error counts and warning counts which differ in
                 # each build / test.
@@ -237,11 +237,83 @@ def plan_json():
                     "kernel_version": "5.12.0-rc6",
                     "status_message": "build completed",
                 },
+                {
+                    "project": "tuxsuite/senthil",
+                    "uid": "1qsx3vvpbsyQS7gVwfdwBHZzcCY",
+                    "plan": "1qsx3P3UROY9DwTUV48cEre3UO7",
+                    "kconfig": ["defconfig"],
+                    "target_arch": "x86_64",
+                    "toolchain": "clang-nightly",
+                    "build_name": "",
+                    "client_token": "537c0a39-5919-48a3-96c2-31773aaae988",
+                    "environment": {},
+                    "make_variables": {},
+                    "targets": [],
+                    "git_repo": "https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git",
+                    "git_ref": "master",
+                    "git_sha": "454859c552da78b0f587205d308401922b56863e",
+                    "download_url": "https://builds.tuxbuild.com/1qsx3vvpbsyQS7gVwfdwBHZzcCY/",
+                    "kernel_image": "",
+                    "user": "senthil.kumaran@linaro.org",
+                    "user_agent": None,
+                    "state": "finished",
+                    "result": "canceled",  # case: Plan Canceled
+                    "waited_by": ["1qsx5iBMtsjD24OgjWW9tatj4HG"],
+                    "errors_count": 1,
+                    "warnings_count": 4,
+                    "kernel_patch_file": None,
+                    "provisioning_time": "2021-11-01T19:38:31.161747",
+                    "running_time": None,
+                    "finished_time": None,
+                    "git_short_log": "454859c552da (\"Merge tag 'arc-5.12-rc7'\")",
+                    "kernel_image_name": "bzImage",
+                    "duration": 40,
+                    "build_status": "error",
+                    "tuxbuild_status": "complete",
+                    "kernel_version": "5.12.0-rc6",
+                    "status_message": "build canceled",
+                },
+                {
+                    "project": "tuxsuite/senthil",
+                    "uid": "1qsx3vvpbsyQS7gVwfdwBHZzcCR",
+                    "plan": "1qsx3P3UROY9DwTUV48cEre3UO7",
+                    "kconfig": ["defconfig"],
+                    "target_arch": "x86_64",
+                    "toolchain": "clang-nightly",
+                    "build_name": "",
+                    "client_token": "537c0a39-5919-48a3-96c2-31773aaae988",
+                    "environment": {},
+                    "make_variables": {},
+                    "targets": [],
+                    "git_repo": "https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git",
+                    "git_ref": "master",
+                    "git_sha": "454859c552da78b0f587205d308401922b56863e",
+                    "download_url": "https://builds.tuxbuild.com/1qsx3vvpbsyQS7gVwfdwBHZzcCR/",
+                    "kernel_image": "",
+                    "user": "senthil.kumaran@linaro.org",
+                    "user_agent": None,
+                    "state": "finished",
+                    "result": "unknown",  # case: result unknown
+                    "waited_by": ["1qsx5iBMtsjD24OgjWW9tatj4HF"],
+                    "errors_count": 1,
+                    "warnings_count": 4,
+                    "kernel_patch_file": None,
+                    "provisioning_time": "2021-11-01T19:38:31.161747",
+                    "running_time": None,
+                    "finished_time": None,
+                    "git_short_log": "454859c552da (\"Merge tag 'arc-5.12-rc7'\")",
+                    "kernel_image_name": "bzImage",
+                    "duration": 40,
+                    "build_status": "error",
+                    "tuxbuild_status": "complete",
+                    "kernel_version": "5.12.0-rc6",
+                    "status_message": "build running",
+                },
             ],
             "next": None,
         },
         "tests": {
-            "count": 6,
+            "count": 8,
             "results": [
                 {
                     "project": "tuxsuite/senthil",
@@ -299,6 +371,62 @@ def plan_json():
                     "finished_time": "2021-04-08T11:47:39.082080",
                     "duration": 45,
                 },
+                {
+                    "project": "tuxsuite/senthil",
+                    "device": "qemu-x86_64",
+                    "uid": "1qsx5iBMtsjD24OgjWW9tatj4HG",
+                    "kernel": "https://builds.tuxbuild.com/1qsx3vvpbsyQS7gVwfdwBHZzcCY/bzImage",
+                    "ap_romfw": None,
+                    "mcp_fw": None,
+                    "mcp_romfw": None,
+                    "modules": None,
+                    "parameters": None,
+                    "rootfs": None,
+                    "scp_fw": None,
+                    "scp_romfw": None,
+                    "fip": None,
+                    "tests": ["boot", "ltp-smoke"],
+                    "user": None,
+                    "user_agent": None,
+                    "state": "finished",  # case: status finished
+                    "result": "canceled",  # case: result canceled
+                    "results": {"boot": "unknown", "ltp-smoke": "canceled"},
+                    "plan": "1qsx3P3UROY9DwTUV48cEre3UO7",
+                    "waiting_for": "1qsx3vvpbsyQS7gVwfdwBHZzcCY",
+                    "boot_args": None,
+                    "provisioning_time": "2021-04-08T11:46:53.297621",
+                    "running_time": "2021-04-08T11:46:54.355808",
+                    "finished_time": "2021-04-08T11:47:39.082080",
+                    "duration": 45,
+                },
+                {
+                    "project": "tuxsuite/senthil",
+                    "device": "qemu-x86_64",
+                    "uid": "1qsx5iBMtsjD24OgjWW9tatj4HF",
+                    "kernel": "https://builds.tuxbuild.com/1qsx3vvpbsyQS7gVwfdwBHZzcCR/bzImage",
+                    "ap_romfw": None,
+                    "mcp_fw": None,
+                    "mcp_romfw": None,
+                    "modules": None,
+                    "parameters": None,
+                    "rootfs": None,
+                    "scp_fw": None,
+                    "scp_romfw": None,
+                    "fip": None,
+                    "tests": ["boot", "ltp-smoke"],
+                    "user": None,
+                    "user_agent": None,
+                    "state": "finished",  # case: status running
+                    "result": "unknown",  # case: result unknown
+                    "results": {"boot": "fail", "ltp-smoke": "pass"},
+                    "plan": "1qsx3P3UROY9DwTUV48cEre3UO7",
+                    "waiting_for": "1qsx3vvpbsyQS7gVwfdwBHZzcCR",
+                    "boot_args": None,
+                    "provisioning_time": "2021-04-08T11:46:53.297621",
+                    "running_time": "2021-04-08T11:46:54.355808",
+                    "finished_time": "2021-04-08T11:47:39.082080",
+                    "duration": 45,
+                },
                 {
                     "project": "tuxsuite/senthil",
                     "device": "qemu-x86_64",
@@ -374,7 +502,7 @@ def plan_json():
                     "user_agent": None,
                     "state": "finished",
                     "result": "fail",  # case: result fail
-                    "results": {"boot": "fail", "ltp-smoke": "pass"},
+                    "results": {"boot": "unknown", "ltp-smoke": "pass"},
                     "plan": "1qsx3P3UROY9DwTUV48cEre3UO7",
                     "waiting_for": None,  # case: standalone test
                     "boot_args": None,
@@ -401,7 +529,7 @@ def plan_json():
                     "user": None,
                     "user_agent": None,
                     "state": "finished",
-                    "result": "error",  # case: result error
+                    "result": "canceled",  # case: result error
                     "results": {"boot": "fail", "ltp-smoke": "pass"},
                     "plan": "1qsx3P3UROY9DwTUV48cEre3UO7",
                     "waiting_for": None,  # case: standalone test
@@ -430,7 +558,7 @@ def bake_plan_json():
         "user_agent": "tuxsuite/0.43.10",
         "provisioning_time": "2022-05-16T06:06:33.830964",
         "oebuilds": {
-            "count": 2,
+            "count": 4,
             "results": [
                 {
                     "project": "tuxsuite/alok",
@@ -502,6 +630,76 @@ def bake_plan_json():
                     "duration": 7021,
                     "status_message": "",
                 },
+                {
+                    "project": "tuxsuite/alok",
+                    "uid": "29EbSyjM7FZgX1X2FDvpq0hxomR",
+                    "plan": "29EbSmPfjpbYQj8ZuaBpsiA8CbW",
+                    "distro": "rpb",
+                    "machine": "ledge-multi-armv7",
+                    "container": "ubuntu-20.04",
+                    "environment": {},
+                    "local_conf": [],
+                    "bblayers_conf": [],
+                    "artifacts": [],
+                    "target": "rpb-console-image rpb-console-image-test rpb-desktop-image rpb-desktop-image-test",
+                    "envsetup": "setup-environment",
+                    "user": "alok.ranjan@linaro.org",
+                    "user_agent": "tuxsuite/0.43.10",
+                    "download_url": "https://oebuilds.tuxbuild.com/29EbSyjM7FZgX1X2FDvpq0hxomR/",
+                    "sources": {
+                        "repo": {
+                            "branch": "qcom/dunfell",
+                            "manifest": "default.xml",
+                            "url": "https://github.com/96boards/oe-rpb-manifest.git",
+                        }
+                    },
+                    "state": "finished",
+                    "result": "canceled",  # case canceled oebuild
+                    "waited_by": [],
+                    "errors_count": 0,
+                    "warnings_count": 0,
+                    "running_time": "2022-05-16T06:09:04.713320",
+                    "finished_time": "2022-05-16T06:09:46.534596",
+                    "manifest_file": "None",
+                    "provisioning_time": "2022-05-16T06:06:35.312535",
+                    "duration": 45,
+                    "status_message": "oebuild canceled",
+                },
+                {
+                    "project": "tuxsuite/alok",
+                    "uid": "29EbSyjM7FZgX1X2FDvpq0hxomF",
+                    "plan": "29EbSmPfjpbYQj8ZuaBpsiA8CbW",
+                    "distro": "rpb",
+                    "machine": "ledge-multi-armv7",
+                    "container": "ubuntu-20.04",
+                    "environment": {},
+                    "local_conf": [],
+                    "bblayers_conf": [],
+                    "artifacts": [],
+                    "target": "rpb-console-image rpb-console-image-test rpb-desktop-image rpb-desktop-image-test",
+                    "envsetup": "setup-environment",
+                    "user": "alok.ranjan@linaro.org",
+                    "user_agent": "tuxsuite/0.43.10",
+                    "download_url": "https://oebuilds.tuxbuild.com/29EbSyjM7FZgX1X2FDvpq0hxomF/",
+                    "sources": {
+                        "repo": {
+                            "branch": "qcom/dunfell",
+                            "manifest": "default.xml",
+                            "url": "https://github.com/96boards/oe-rpb-manifest.git",
+                        }
+                    },
+                    "state": "finished",
+                    "result": "unknown",  # case unknown oebuild
+                    "waited_by": [],
+                    "errors_count": 0,
+                    "warnings_count": 0,
+                    "running_time": "2022-05-16T06:09:04.713320",
+                    "finished_time": "2022-05-16T06:09:46.534596",
+                    "manifest_file": "None",
+                    "provisioning_time": "2022-05-16T06:06:35.312535",
+                    "duration": 45,
+                    "status_message": "oebuild still unknown",
+                },
             ],
             "next": None,
         },
@@ -573,6 +771,32 @@ def test_plan_handle_get(mocker, plan_json, config, response, monkeypatch):
     tuxsuite.cli.main()
 
 
+def test_plan_handle_cancel(mocker, plan_json, config, response, monkeypatch):
+    monkeypatch.setattr(
+        sys, "argv", ["tuxsuite", "plan", "cancel", "1tOhlD2nkPsRNNTMB5Lj09n1IVQ"]
+    )
+    response.status_code = 200
+    response._content = plan_json
+    post_req = mocker.patch("requests.post", return_value=response)
+    tuxsuite.cli.main()
+    post_req.assert_called_with(
+        "https://tuxapi.tuxsuite.com/v1/groups/tuxsuite/projects/tux/plans/1tOhlD2nkPsRNNTMB5Lj09n1IVQ/cancel",
+        headers={
+            "User-Agent": "tuxsuite.cli/0.1",
+            "Authorization": "Q9qMlmkjkIuIGmEAw-Mf53i_qoJ8Z2eGYCmrNx16ZLLQGrXAHRiN2ce5DGlAebOmnJFp9Ggcq9l6quZdDTtrkw",
+        },
+        json={},
+    )
+    assert post_req.call_count == 1
+
+    # Test failure case when the response is not 200
+    response.status_code = 500
+    post_req = mocker.patch("requests.post", return_value=response)
+    with pytest.raises(tuxsuite.exceptions.URLNotFound):
+        tuxsuite.cli.main()
+    assert post_req.call_count == 1
+
+
 def test_plan_handle_list(mocker, plan_list_json, config, response, monkeypatch):
     monkeypatch.setattr(sys, "argv", ["tuxsuite", "plan", "list"])
     monkeypatch.setattr("sys.stdout.isatty", lambda: True)
