@@ -664,12 +664,16 @@ def test_watch(config, mocker, plan_config):
         tuxsuite.build.Build(**build_attrs, uid="build-2"),
         tuxsuite.build.Build(**build_attrs, uid="build-3"),
         tuxsuite.build.Build(**build_attrs, uid="build-4"),
+        tuxsuite.build.Build(**build_attrs, uid="build-5"),
+        tuxsuite.build.Build(**build_attrs, uid="build-6"),
     ]
     plan.tests = [
         tuxsuite.build.Test(**test_attrs, uid="test-1"),
         tuxsuite.build.Test(**test_attrs, uid="test-2"),
         tuxsuite.build.Test(**test_attrs, uid="test-3"),
         tuxsuite.build.Test(**test_attrs, uid="test-4"),
+        tuxsuite.build.Test(**test_attrs, uid="test-5"),
+        tuxsuite.build.Test(**test_attrs, uid="test-6"),
     ]
 
     count = 0
@@ -690,12 +694,28 @@ def test_watch(config, mocker, plan_config):
                         "build_status": "pass",
                         "warnings_count": 0,
                     },
+                    "build-5": {
+                        "state": "finished",
+                        "result": "canceled",
+                        "tuxbuild_status": "canceled",
+                        "build_status": "canceled",
+                        "warnings_count": 0,
+                    },
+                    "build-6": {
+                        "state": "finished",
+                        "result": "unknown",
+                        "tuxbuild_status": "unknown",
+                        "build_status": "unknown",
+                        "warnings_count": 0,
+                    },
                 },
                 "tests": {
                     "test-1": {"state": "waiting", "result": "unknown"},
                     "test-2": {"state": "provisioning", "result": "unknown"},
                     "test-3": {"state": "running", "result": "unknown"},
                     "test-4": {"state": "finished", "result": "pass"},
+                    "test-5": {"state": "finished", "result": "canceled"},
+                    "test-6": {"state": "finished", "result": "unknown"},
                 },
             }
         if count == 2:
@@ -729,19 +749,35 @@ def test_watch(config, mocker, plan_config):
                         "build_status": "pass",
                         "warnings_count": 0,
                     },
+                    "build-5": {
+                        "state": "finished",
+                        "result": "canceled",
+                        "tuxbuild_status": "canceled",
+                        "build_status": "canceled",
+                        "warnings_count": 0,
+                    },
+                    "build-6": {
+                        "state": "finished",
+                        "result": "unknown",
+                        "tuxbuild_status": "unknown",
+                        "build_status": "unknown",
+                        "warnings_count": 0,
+                    },
                 },
                 "tests": {
                     "test-1": {"state": "finished", "result": "pass"},
                     "test-2": {"state": "finished", "result": "pass"},
                     "test-3": {"state": "finished", "result": "pass"},
                     "test-4": {"state": "finished", "result": "pass"},
+                    "test-5": {"state": "finished", "result": "canceled"},
+                    "test-6": {"state": "finished", "result": "unknown"},
                 },
             }
         assert 0
 
     plan.get_plan = get_plan
     states = list(plan.watch())
-    assert len(states) == 14
+    assert len(states) == 18
     assert states[0].build.uid == "build-1"
     assert states[0].state == "queue"
     assert states[1].build.uid == "build-2"
@@ -750,27 +786,35 @@ def test_watch(config, mocker, plan_config):
     assert states[2].state == "running"
     assert states[3].build.uid == "build-4"
     assert states[3].state == "pass"
-    assert states[4].build.uid == "test-1"
-    assert states[4].state == "waiting"
-    assert states[5].build.uid == "test-2"
-    assert states[5].state == "provisioning"
-    assert states[6].build.uid == "test-3"
-    assert states[6].state == "running"
-    assert states[7].build.uid == "test-4"
-    assert states[7].state == "finished"
+    assert states[4].build.uid == "build-5"
+    assert states[4].build.status["result"] == "canceled"
+    assert states[5].build.uid == "build-6"
+    assert states[5].build.status["result"] == "unknown"
+    assert states[6].build.uid == "test-1"
+    assert states[6].state == "waiting"
+    assert states[7].build.uid == "test-2"
+    assert states[7].state == "provisioning"
+    assert states[8].build.uid == "test-3"
+    assert states[8].state == "running"
+    assert states[9].build.uid == "test-4"
+    assert states[9].state == "finished"
+    assert states[10].build.uid == "test-5"
+    assert states[10].build.status["result"] == "canceled"
+    assert states[11].build.uid == "test-6"
+    assert states[11].build.status["result"] == "unknown"
 
-    assert states[8].build.uid == "build-1"
-    assert states[8].state == "pass"
-    assert states[9].build.uid == "build-2"
-    assert states[9].state == "pass"
-    assert states[10].build.uid == "build-3"
-    assert states[10].state == "pass"
-    assert states[11].build.uid == "test-1"
-    assert states[11].state == "finished"
-    assert states[12].build.uid == "test-2"
-    assert states[12].state == "finished"
-    assert states[13].build.uid == "test-3"
-    assert states[13].state == "finished"
+    assert states[12].build.uid == "build-1"
+    assert states[12].state == "pass"
+    assert states[13].build.uid == "build-2"
+    assert states[13].state == "pass"
+    assert states[14].build.uid == "build-3"
+    assert states[14].state == "pass"
+    assert states[15].build.uid == "test-1"
+    assert states[15].state == "finished"
+    assert states[16].build.uid == "test-2"
+    assert states[16].state == "finished"
+    assert states[17].build.uid == "test-3"
+    assert states[17].state == "finished"
 
 
 def test_bake_watch(config, mocker, bake_plan_config):
@@ -825,16 +869,16 @@ def test_bake_watch(config, mocker, bake_plan_config):
                 "builds": {
                     "bake_build-1": {
                         "state": "finished",
-                        "result": "pass",
-                        "tuxbuild_status": "pass",
-                        "build_status": "pass",
+                        "result": "unknown",
+                        "tuxbuild_status": "unknown",
+                        "build_status": "unknown",
                         "warnings_count": 0,
                     },
                     "bake_build-2": {
                         "state": "finished",
-                        "result": "pass",
-                        "tuxbuild_status": "pass",
-                        "build_status": "pass",
+                        "result": "canceled",
+                        "tuxbuild_status": "canceled",
+                        "build_status": "canceled",
                         "warnings_count": 0,
                     },
                     "bake_build-3": {
@@ -861,9 +905,9 @@ def test_bake_watch(config, mocker, bake_plan_config):
     assert states[2].state == "finished"
 
     assert states[3].build.uid == "bake_build-1"
-    assert states[3].state == "finished"
+    assert states[3].build.status["result"] == "unknown"
     assert states[4].build.uid == "bake_build-2"
-    assert states[4].state == "finished"
+    assert states[4].build.status["result"] == "canceled"
 
 
 def test_config_url(get, response, sample_plan_config):
