@@ -5,7 +5,7 @@
 This is the tuxsuite module.
 """
 
-__version__ = "1.6.0"
+__version__ = "1.7.1"
 
 
 from . import build
@@ -181,7 +181,6 @@ class BuildPlan(PlanType):
                 # Ignore bake plan options
                 data.pop("manifest_file", None)
                 data.pop("pinned_manifest", None)
-                data.pop("is_public", None)
 
                 data.update(cfg["build"])
                 if plan.args.get("no_cache"):
@@ -228,10 +227,7 @@ class BakePlan(PlanType):
                     plan_config.plan.append({"build": build_item, "tests": []})
 
     def plan_info(self, name, description):
-        print(
-            "*** WARNING: BITBAKE SUPPORT IS EXPERIMENTAL ***\n"
-            "Running Bake plan '{}': '{}'".format(name, description)
-        )
+        print("Running Bake plan '{}': '{}'".format(name, description))
 
     def create_builds(self, plan, builds):
         req_data = {"oebuilds": []}
