@@ -60,8 +60,29 @@ def get_request(url, headers, params=None):
 
 def download_patch_with_b4(patch_path):
     if shutil.which("b4"):
-        patch_file = tempfile.NamedTemporaryFile(suffix=".mbx").name
-        subprocess.check_output(["b4", "am", "-n", patch_file, patch_path])
+        patch_file = os.path.join(
+            tempfile.gettempdir(),
+            f"{hashlib.sha256(patch_path.encode()).hexdigest()}.mbox",
+        )
+        patch_file_mbx = os.path.join(
+            tempfile.gettempdir(),
+            f"{hashlib.sha256(patch_path.encode()).hexdigest()}.mbx",
+        )
+        if os.path.exists(patch_file):
+            m_time = os.path.getctime(patch_file)
+            time_delta_seconds = time.time() - m_time
+            # Check if the patch file is older than 3 minutes before download
+            if time_delta_seconds > 180.0:
+                os.remove(patch_file)
+                subprocess.check_output(["b4", "am", "-n", patch_file, patch_path])
+        else:
+            subprocess.check_output(["b4", "am", "-n", patch_file, patch_path])
+
+        # We need this rename from *.mbx to *.mbox, due to a bug in b4,
+        # where it always downloads the patch with a *.mbx extension and
+        # not with the specified extension
+        if os.path.exists(patch_file_mbx):
+            os.rename(patch_file_mbx, patch_file)
         patch_path = patch_file
         patch_file = os.path.basename(patch_file)
         return (patch_file, patch_path)
@@ -78,9 +99,9 @@ def handle_patch(patch_path):
     patch_content = None
     patch_file = os.path.basename(patch_path)
     if "lore.kernel.org" in patch_path:
+        patch_type = "lore"
         patch_file, patch_path = download_patch_with_b4(patch_path)
-
-    if urlparse(patch_path).scheme in ["http", "https"]:
+    elif urlparse(patch_path).scheme in ["http", "https"]:
         patch_type = "url"
     elif os.path.isfile(patch_path):
         patch_type = "file"
@@ -94,7 +115,7 @@ def handle_patch(patch_path):
         patch_file = patch_path
         patch_content = b""
         patch_is_web_url = True
-    elif patch_type in ["file", "message-id"]:
+    elif patch_type in ["lore", "file", "message-id"]:
         # Rename .mbx to .mbox on the fly.
         if pathlib.Path(patch_path).suffix == ".mbx":
             new_patch_path = os.path.join(
@@ -215,6 +236,7 @@ class Build(HeadersMixin):
     json = attrib(default=False)
     limit = attrib(default=0)
     no_cache = attrib(default=False)
+    is_public = attrib(default=True)
 
     def __attrs_post_init__(self):
         if isinstance(self.kconfig, str):
@@ -264,6 +286,8 @@ class Build(HeadersMixin):
         build_entry["environment"] = dict(self.environment)
         build_entry["targets"] = self.targets
         build_entry["make_variables"] = self.make_variables
+        if self.is_public is not None:
+            build_entry["is_public"] = self.is_public
         if self.kernel_image:
             build_entry["kernel_image"] = self.kernel_image
         if self.build_name:
@@ -424,6 +448,14 @@ class Build(HeadersMixin):
             error_message = self.status.get("status_message")
             if error_message:
                 message += f" with status message '{error_message}'"
+        elif status == "canceled":
+            icon = "⚠️ "
+            cli_color = "white"
+            message = "Canceled"
+        elif status == "unknown":
+            icon = "🧐"
+            cli_color = "purple"
+            message = "Unknown"
         else:
             icon = "🔧"
             cli_color = "bright_red"
@@ -761,6 +793,18 @@ class Plan(HeadersMixin):
 
         return self.filter_builds(__filter)
 
+    def canceled(self):
+        def __filter(plan, build):
+            return build.status["result"] == "canceled"
+
+        return self.filter_builds(__filter)
+
+    def unknown(self):
+        def __filter(plan, build):
+            return build.status["result"] == "unknown"
+
+        return self.filter_builds(__filter)
+
     def watch(self):
         n_builds = len(self.builds)
         n_tests = len(self.tests)
@@ -954,6 +998,14 @@ class Test(HeadersMixin):
             ]
             message = "Fail ({})".format(", ".join(errors))
             errors = len(errors)
+        elif result == "canceled":
+            icon = "⚠️ "
+            cli_color = "white"
+            message = "Canceled"
+        elif result == "unknown":
+            icon = "🧐"
+            cli_color = "purple"
+            message = "Unknown"
         else:
             icon = "🔧"
             cli_color = "bright_red"
@@ -1208,6 +1260,14 @@ class Bitbake(HeadersMixin):
             error_message = self.status.get("status_message")
             if error_message:
                 message += f" with status message '{error_message}'"
+        elif status == "canceled":
+            icon = "⚠️ "
+            cli_color = "white"
+            message = "Canceled"
+        elif status == "unknown":
+            icon = "🧐"
+            cli_color = "purple"
+            message = "Unknown"
         else:
             icon = "🔧"
             cli_color = "bright_red"
