@@ -6,7 +6,7 @@ import tuxsuite.cli.colors as colors
 import tuxsuite.cli.icons as icons
 from tuxsuite.cli.common import common_options
 from tuxsuite.cli.models import Build
-from tuxsuite.cli.requests import apiurl, get
+from tuxsuite.cli.requests import apiurl, get, post, headers
 from tuxsuite.cli.utils import (
     LIMIT,
     datediff,
@@ -47,7 +47,7 @@ def handle_config(options, _, config):
         raise NotImplementedError()
 
     # TODO: add a wrapper around requests.get
-    ret = requests.get(f"{ret.json()['download_url']}config")
+    ret = requests.get(f"{ret.json()['download_url']}config", headers=headers(config))
     if ret.status_code != 200:
         raise NotImplementedError()
     print(ret.text)
@@ -95,6 +95,10 @@ def handle_get(options, _, config):
                 icon = icons.ERROR
             elif build.result == "fail":
                 icon = icons.FAIL
+            elif build.result == "unknown":
+                icon = icons.UNKNOWN
+            elif build.result == "canceled":
+                icon = icons.CANCELED
             print(f"{icon} time  : {build.finished_time}")
         if build.duration:
             print(f"duration : {build.duration}")
@@ -103,8 +107,12 @@ def handle_get(options, _, config):
         color = ""
         if build.result == "pass":
             color = colors.green
+        elif build.result == "canceled":
+            color = colors.white
         elif build.result in ["error", "fail"]:
             color = colors.red
+        elif build.result == "unknown":
+            color = colors.purple
         print(f"result   : {color}{build.result}{colors.reset}")
 
         if build.errors_count:
@@ -115,6 +123,18 @@ def handle_get(options, _, config):
     return 0
 
 
+def handle_cancel(options, _, config):
+    url = f"/v1/groups/{config.group}/projects/{config.project}/builds/{options.uid}/cancel"
+    ret = post(config, url, data={})
+    print(f"canceling job for {options.uid}")
+
+    if ret.status_code != 200:
+        print(f"unable to cancel build {options.uid}")
+        raise tuxsuite.exceptions.URLNotFound()
+
+    return 0
+
+
 def handle_list(options, _, config):
     url = f"/v1/groups/{config.group}/projects/{config.project}/builds"
     ret = get(config, url)
@@ -171,7 +191,9 @@ def handle_logs(options, _, config):
         raise NotImplementedError()
 
     # TODO: add a wrapper around requests.get
-    ret = requests.get(f"{ret.json()['download_url']}build.log")
+    ret = requests.get(
+        f"{ret.json()['download_url']}build.log", headers=headers(config)
+    )
     if ret.status_code != 200:
         raise NotImplementedError()
     print(ret.text)
@@ -229,6 +251,11 @@ def handle_wait(options, _, config):
         icon = icons.ERROR
     elif build.result == "fail":
         icon = icons.FAIL
+    elif build.result == "canceled":
+        icon = icons.CANCELED
+    elif build.result == "unknown":
+        icon = icons.UNKNOWN
+
     print(f"{icon} time  : {build.finished_time}")
     if build.duration:
         print(f"duration : {build.duration}")
@@ -236,6 +263,10 @@ def handle_wait(options, _, config):
     print(f"state    : {build.state}")
     if build.result == "pass":
         color = colors.green
+    elif build.result == "canceled":
+        color = colors.white
+    elif build.result == "unknown":
+        color = colors.purple
     elif build.result in ["error", "fail"]:
         color = colors.red
     print(f"result   : {color}{build.result}{colors.reset}")
@@ -282,6 +313,7 @@ def handle_submit(cmdargs, _, config):
             image_sha=cmdargs.image_sha,
             build_name=cmdargs.build_name,
             no_cache=cmdargs.no_cache,
+            is_public=cmdargs.private,
         )
 
     except (AssertionError, tuxsuite.exceptions.TuxSuiteError) as e:
@@ -302,7 +334,11 @@ def handle_submit(cmdargs, _, config):
     if cmdargs.no_wait:
         format_result(build.status, tuxapi_url=build.build_data)
     else:
-        build_result = wait_for_object(build)
+        try:
+            build_result = wait_for_object(build)
+        except tuxsuite.exceptions.Timeout as exc:
+            build_result = False
+            sys.stderr.write(f"Error: {str(exc)}\n")
 
     if cmdargs.json_out:
         cmdargs.json_out.write(json.dumps(build.status, sort_keys=True, indent=4))
@@ -324,6 +360,7 @@ handlers = {
     "logs": handle_logs,
     "wait": handle_wait,
     "submit": handle_submit,
+    "cancel": handle_cancel,
 }
 
 
@@ -439,4 +476,8 @@ def setup_parser(parser):
     p = parser.add_parser("wait")
     p.add_argument("uid")
 
+    # "build cancel <uid>"
+    t = parser.add_parser("cancel")
+    t.add_argument("uid")
+
     return sorted(parser._name_parser_map.keys())
