@@ -6,7 +6,7 @@ import tuxsuite
 import tuxsuite.cli.colors as colors
 import tuxsuite.cli.icons as icons
 from tuxsuite.cli.models import Plan
-from tuxsuite.cli.requests import get
+from tuxsuite.cli.requests import get, post
 from tuxsuite.cli.common import common_options
 from tuxsuite.cli.utils import (
     LIMIT,
@@ -48,6 +48,14 @@ def format_plan(build, tests):
         icon = icons.ERROR
         color = colors.red
         message = build.status_message
+    elif build.result == "canceled":
+        icon = icons.CANCELED
+        color = colors.white
+        message = build.status_message
+    elif build.result == "unknown":
+        icon = icons.UNKNOWN
+        color = colors.purple
+        message = "Result unknown"
     else:
         raise NotImplementedError()
 
@@ -63,7 +71,12 @@ def format_plan(build, tests):
     tests_error = sorted(
         set(chain.from_iterable([t.tests for t in tests if t.result == "error"]))
     )
-
+    tests_unknown = sorted(
+        set(chain.from_iterable([t.tests for t in tests if t.result == "unknown"]))
+    )
+    tests_canceled = sorted(
+        set(chain.from_iterable([t.tests for t in tests if t.result == "canceled"]))
+    )
     if tests_pass:
         tests_str += (
             f" {icons.PASS} {colors.green}Pass: {','.join(tests_pass)}{colors.reset}"
@@ -76,6 +89,10 @@ def format_plan(build, tests):
         tests_str += (
             f" {icons.ERROR} {colors.red}Error: {','.join(tests_error)}{colors.reset}"
         )
+    if tests_unknown:
+        tests_str += f" {icons.UNKNOWN} {colors.purple}Unknown: {','.join(tests_unknown)}{colors.reset}"
+    if tests_canceled:
+        tests_str += f" {icons.CANCELED} {colors.white}Canceled: {','.join(tests_canceled)}{colors.reset}"
 
     return builds + tests_str
 
@@ -89,6 +106,14 @@ def format_test(test):
         icon = icons.FAIL
         color = colors.red
         message = "Fail"
+    elif test.result == "unknown":
+        icon = icons.UNKNOWN
+        color = colors.purple
+        message = "Unknown"
+    elif test.result == "canceled":
+        icon = icons.CANCELED
+        color = colors.white
+        message = "Canceled"
     elif test.result == "error":
         icon = icons.ERROR
         color = colors.red
@@ -149,7 +174,12 @@ def handle_get(options, _, config):
         )
 
         for build in chain(
-            plan.passing(), plan.warning(), plan.failing(), plan.errors()
+            plan.passing(),
+            plan.warning(),
+            plan.failing(),
+            plan.errors(),
+            plan.canceled(),
+            plan.unknown(),
         ):
             print(format_plan(build, plan._tests_wait_for(build.uid)))
         # Print stand alone tests
@@ -171,6 +201,8 @@ def handle_get(options, _, config):
         )
         failing = len(plan.filter_builds(lambda _, b: b.result == "fail"))
         error = len(plan.filter_builds(lambda _, b: b.result == "error"))
+        canceled = len(plan.filter_builds(lambda _, b: b.result == "canceled"))
+        unknown = len(plan.filter_builds(lambda _, b: b.result == "unknown"))
 
         if provisioning:
             bs += f" {icons.PROVISIONING} {provisioning}"
@@ -184,6 +216,11 @@ def handle_get(options, _, config):
             bs += f" {icons.FAIL} {failing}"
         if error:
             bs += f" {icons.ERROR} {error}"
+        if canceled:
+            bs += f" {icons.CANCELED} {canceled}"
+        if unknown:
+            bs += f" {icons.UNKNOWN} {unknown}"
+
         print(bs)
 
         ts = f"tests ({len(plan.tests)}):"
@@ -193,6 +230,8 @@ def handle_get(options, _, config):
         passing = len(plan.filter_tests(lambda _, t: t.result == "pass"))
         failing = len(plan.filter_tests(lambda _, t: t.result == "fail"))
         error = len(plan.filter_tests(lambda _, t: t.result == "error"))
+        canceled = len(plan.filter_tests(lambda _, t: t.result == "canceled"))
+        unknown = len(plan.filter_tests(lambda _, t: t.result == "unknown"))
 
         if waiting:
             ts += f" {icons.WAITING} {waiting}"
@@ -206,10 +245,26 @@ def handle_get(options, _, config):
             ts += f" {icons.FAIL} {failing}"
         if error:
             ts += f" {icons.ERROR} {error}"
+        if canceled:
+            ts += f" {icons.CANCELED} {canceled}"
+        if unknown:
+            ts += f" {icons.UNKNOWN} {unknown}"
         print(ts)
     return 0
 
 
+def handle_cancel(options, _, config):
+    url = f"/v1/groups/{config.group}/projects/{config.project}/plans/{options.uid}/cancel"
+    ret = post(config, url, data={})
+    print(f"canceling plan {options.uid}")
+
+    if ret.status_code != 200:
+        print("plan not canceled")
+        raise tuxsuite.exceptions.URLNotFound()
+
+    return 0
+
+
 def handle_list(options, _, config):
     url = f"/v1/groups/{config.group}/projects/{config.project}/plans"
     ret = get(config, url)
@@ -297,7 +352,14 @@ def handle_submit(cmdargs, _, config):
     else:
         result = wait_for_object(plan)
         print(f"\nSummary: {plan.url}/plans/{plan.plan}")
-        for b in chain(plan.passing(), plan.warning(), plan.failing(), plan.errors()):
+        for b in chain(
+            plan.passing(),
+            plan.warning(),
+            plan.failing(),
+            plan.errors(),
+            plan.canceled(),
+            plan.unknown(),
+        ):
             format_plan_result(b, plan._tests_wait_for(b.uid))
 
     if cmdargs.json_out:
@@ -318,6 +380,7 @@ handlers = {
     "get": handle_get,
     "list": handle_list,
     "submit": handle_submit,
+    "cancel": handle_cancel,
 }
 
 
@@ -383,4 +446,8 @@ def setup_parser(parser):
     plan_cmd_options(t)
     common_options(t)
 
+    # plan cancel <uid>
+    t = parser.add_parser("cancel")
+    t.add_argument("uid")
+
     return sorted(parser._name_parser_map.keys())
