@@ -104,6 +104,14 @@ def format_result(result_json, tuxapi_url=None, prefix=""):
                     message = "Pass (1 warning)"
                 else:
                     message = "Pass ({} warnings)".format(warnings)
+        elif result == "canceled":
+            icon = "⚠️ "
+            cli_color = "white"
+            message = "Canceled"
+        elif result == "unknown":
+            icon = "🧐"
+            cli_color = "purple"
+            message = "Unknown"
         elif result == "fail":
             icon = "👹"
             cli_color = "bright_red"
@@ -240,6 +248,14 @@ def format_plan_result(build, tests):
                 message = "Pass (1 warning)"
             else:
                 message = "Pass ({} warnings)".format(build.status["warnings_count"])
+    elif build.status["result"] == "canceled":
+        icon = "⚠️ "
+        cli_color = "white"
+        message = "Canceled"
+    elif build.status["result"] == "unknown":
+        icon = "🧐"
+        cli_color = "purple"
+        message = "Unknown"
     elif build.status["result"] == "fail":
         fail = False
         icon = "👹"
@@ -273,6 +289,20 @@ def format_plan_result(build, tests):
             )
         )
     )
+    tests_canceled = sorted(
+        set(
+            chain.from_iterable(
+                [t.tests for t in tests if t.status["result"] == "canceled"]
+            )
+        )
+    )
+    tests_unknown = sorted(
+        set(
+            chain.from_iterable(
+                [t.tests for t in tests if t.status["result"] == "unknown"]
+            )
+        )
+    )
     tests_error = sorted(
         set(
             chain.from_iterable(
@@ -287,7 +317,10 @@ def format_plan_result(build, tests):
         tests_str += " 👹 " + f"Fail: {','.join(tests_fail)}"
     if tests_error:
         tests_str += " 🔧 " + f"Error: {','.join(tests_error)}"
-
+    if tests_canceled:
+        tests_str += " ⚠️  " + f"Canceled: {','.join(tests_canceled)}"
+    if tests_unknown:
+        tests_str += " 🧐 " + f"Unknown: {','.join(tests_unknown)}"
     if fail or tests_fail or tests_error:
         print(builds + tests_str)
     else:
